emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] emacs-24 b5c9c13: Spelling fixes


From: Paul Eggert
Subject: [Emacs-diffs] emacs-24 b5c9c13: Spelling fixes
Date: Sun, 28 Dec 2014 23:06:21 +0000

branch: emacs-24
commit b5c9c131ca4c0382d32ccb9c59c02a0392276503
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    Spelling fixes
---
 lisp/progmodes/python.el |    8 ++++----
 nt/ChangeLog             |    2 +-
 src/ChangeLog.10         |    2 +-
 src/ChangeLog.12         |    4 ++--
 4 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/nt/ChangeLog b/nt/ChangeLog
index e657e2b..566af1a 100644
--- a/nt/ChangeLog
+++ b/nt/ChangeLog
@@ -725,7 +725,7 @@
 2012-10-01  Eli Zaretskii  <address@hidden>
 
        * preprep.c (RVA_TO_PTR): Use 'unsigned char *' instead of
-       'void *', for pointer arithmetics.
+       'void *', for pointer arithmetic.
        (OFFSET_TO_RVA, RVA_TO_OFFSET, RVA_TO_SECTION_OFFSET): Enclose all
        macro arguments in parentheses.
 
diff --git a/src/ChangeLog.10 b/src/ChangeLog.10
index 1b77eaf..f6d602b 100644
--- a/src/ChangeLog.10
+++ b/src/ChangeLog.10
@@ -2826,7 +2826,7 @@
 2006-07-21  Eli Zaretskii  <address@hidden>
 
        * w32.c (convert_time): Use explicit long double constants to
-       ensure long double arithmetics is used throughout.
+       ensure long double arithmetic is used throughout.
 
 2006-07-20  YAMAMOTO Mitsuharu  <address@hidden>
 
diff --git a/src/ChangeLog.12 b/src/ChangeLog.12
index 80d7460..60f9ea2 100644
--- a/src/ChangeLog.12
+++ b/src/ChangeLog.12
@@ -2327,7 +2327,7 @@
 
 2012-12-08  Fabrice Popineau  <address@hidden>
 
-       * w32fns.c (emacs_abort): Don't do arithmetics on void pointers.
+       * w32fns.c (emacs_abort): Don't do arithmetic on void pointers.
 
 2012-12-08  Eli Zaretskii  <address@hidden>
 
@@ -4716,7 +4716,7 @@
        defining an XRectangle structure.
 
        * w32proc.c (RVA_TO_PTR, w32_executable_type): Fix pointer
-       arithmetics for compatibility with x64.
+       arithmetic for compatibility with x64.
 
        * w32menu.c (add_menu_item): Use UINT_PTR instead of UINT, for
        compatibility with x64.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/progmodes/python.el b/lisp/progmodes/python.el
index 0d80110..c16b261 100644
--- a/lisp/progmodes/python.el
+++ b/lisp/progmodes/python.el
@@ -2531,7 +2531,7 @@ the python shell:
                     (concat
                      (format "# -*- coding: %s -*-\n" encoding)
                      (make-string
-                      ;; Substract 2 because of the coding cookie.
+                      ;; Subtract 2 because of the coding cookie.
                       (- (line-number-at-pos start) 2) ?\n))))
          (toplevel-block-p (save-excursion
                              (goto-char start)
@@ -3951,7 +3951,7 @@ operator."
 
 (defun python-info-encoding-from-cookie ()
   "Detect current buffer's encoding from its coding cookie.
-Returns the enconding as a symbol."
+Returns the encoding as a symbol."
   (let ((first-two-lines
          (save-excursion
            (save-restriction
@@ -3968,9 +3968,9 @@ Returns the enconding as a symbol."
   "Return encoding for file.
 Try `python-info-encoding-from-cookie', if none is found then
 default to utf-8."
   ;; If no enconding is defined, then it's safe to use UTF-8: Python 2
   ;; uses ASCII as default while Python 3 uses UTF-8.  This means that
-  ;; in the worst case escenario python.el will make things work for
+  ;; in the worst case scenario python.el will make things work for
   ;; Python 2 files with unicode data and no encoding defined.
   (or (python-info-encoding-from-cookie)
       'utf-8))
@@ -3968,9 +3968,9 @@ Returns the enconding as a symbol."
 Try `python-info-encoding-from-cookie', if none is found then
 default to utf-8."
-  ;; If no enconding is defined, then it's safe to use UTF-8: Python 2
+  ;; If no encoding is defined, then it's safe to use UTF-8: Python 2
   ;; uses ASCII as default while Python 3 uses UTF-8.  This means that